@@ -2,6 +2,8 @@
 """ API for AWS Content Management """
 
 
+from typing import Optional
+
 from baseblock import EnvIO
 from baseblock import BaseObject
 
@@ -15,7 +17,9 @@ from awsfile_helper.svc import FindFileByVersion
 class AwsAPI(BaseObject):
     """ API for AWS Content Management """
 
-    def __init__(self):
+    def __init__(self,
+                 aws_access_key: Optional[str] = None,
+                 aws_secret_key: Optional[str] = None):
         """ Change Log
 
         Created:
@@ -27,13 +31,31 @@ class AwsAPI(BaseObject):
             craigtrim@gmail.com
             *   adhere to latest standard on file version
                 https://bast-ai.atlassian.net/browse/COR-59
+        Updated:
+            11-Nov-2022
+            craigtrim@gmail.com
+            *   pass keys as parameters
+                https://github.com/craigtrim/awsfile-helper/issues/4
+
+        Args:
+            aws_access_key (str, Optional): Encrypted AWS Access Key
+                if the key is not provided as a parameter,
+                it must be encrypted within the environment as AWS_ACCESS_KEY
+            aws_secret_key (str, Optional): Encrypted AWS Secret Key
+                if the key is not provided as a parameter,
+                it must be encrypted within the environment as AWS_SECRET_KEY
         """
         BaseObject.__init__(self, __name__)
-        self._s3 = ConnectToS3().process()
-        self._download_files = DownloadFromS3(self._s3).process
+
+        self._s3 = ConnectToS3(
+            aws_access_key=aws_access_key,
+            aws_secret_key=aws_secret_key).process()
+
         self._read_files = ReadFromS3(self._s3).process
         self._find_latest_version_number = FindLatestVersionNumber(
             self._read_files).process
+
+        self._download_files = DownloadFromS3(self._s3).process
         self._find_file_by_version = FindFileByVersion(
             self._download_files).process
 
