@@ -7,6 +7,7 @@ import botocore
 
 from boto3.resources.factory import ServiceResource
 
+from baseblock import EnvIO
 from baseblock import FileIO
 from baseblock import BaseObject
 
@@ -22,9 +23,16 @@ class S3ImageWriter(BaseObject):
             11-Oct-2022
             craigtrim@gmail.com
             *   https://github.com/craigtrim/awsfile-helper/issues/1
+        Updated:
+            1-Nov-2022
+            craigtrim@gmail.com
+            *   retrieve local directory from environment
+                https://github.com/craigtrim/awsfile-helper/issues/3
         """
         BaseObject.__init__(self, __name__)
         self._s3 = s3
+        self._local_directory = FileIO.local_directory_by_name(
+            EnvIO.str_or_default('LOCAL_DIRECTORY_NAME', 'AWSFileHelper'))
 
     def process(self,
                 bucket_name: str,
@@ -39,8 +47,7 @@ class S3ImageWriter(BaseObject):
             str: the file path of the image
         """
 
-        file_path = FileIO.join(
-            FileIO.local_directory_by_name('Graffl'), file_name)
+        file_path = FileIO.join(self._local_directory, file_name)
 
         if FileIO.exists(file_path):
             return file_path
